@@ -226,6 +226,11 @@ public final class Main
    * true when -all has been specified on the command line.
    */
   private boolean option_all;
+
+  /**
+   * true when -reflection has been specified on the command line.
+   */
+  private boolean option_reflection;
   
   // TODO: add the rest of the options as instance variables
   
@@ -553,7 +558,7 @@ public final class Main
           .toArray(new String[0][0]);
       if (validOptionsMethod != null
           && !((Boolean) validOptionsMethod.invoke(null, new Object[]
-            { customOptionArr, this })).booleanValue())
+            { customOptionArr, reporter })).booleanValue())
       {
         // Not ok: shutdown system.
         shutdown();
@@ -767,6 +772,82 @@ public final class Main
     }
   }
 
+  /**
+   * Parses command line arguments and subsequentially handles control to the
+   * startDoclet() method
+   *   
+   * @param args The command line parameters.
+   */
+   public static int execute(String[] args)
+   {
+     try
+     {
+       instance.start(args);
+     }
+     catch (Exception e)
+     {
+       return 1;
+     }
+ 
+     return 0;
+   }
+
+  /**
+   * @param programName Name of the program (for error messages). *disregarded*
+   * @param args The command line parameters.
+   * @returns The return code.
+   */
+  public static int execute(String programName,
+                            String[] args)
+  {
+    return execute(args);
+  }
+ 
+  /**
+   * @param programName Name of the program (for error messages).
+   * @param defaultDocletClassName Fully qualified class name.
+   * @param args The command line parameters.
+   * @returns The return code.
+   *//*
+  public static int execute(String programName,
+                            String defaultDocletClassName,
+                            String[] args)
+  {
+    // not yet implemented
+  }*/
+ 
+  /**
+   * @param programName Name of the program (for error messages).
+   * @param defaultDocletClassName Fully qualified class name.
+   * @param args The command line parameters.
+   * @returns The return code.
+   *//*
+  public static int execute(String programName,
+                            String defaultDocletClassName,
+                            String[] args)
+  {
+    // not yet implemented
+  }*/
+ 
+  /**
+   * @param programName Name of the program (for error messages).
+   * @param errWriter PrintWriter to receive error messages.
+   * @param warnWriter PrintWriter to receive error messages.
+   * @param noticeWriter PrintWriter to receive error messages.
+   * @param defaultDocletClassName Fully qualified class name.
+   * @param args The command line parameters.
+   * @returns The return code.
+   *//*
+  public static int execute(String programName,
+                            PrintWriter errWriter,
+                            PrintWriter warnWriter,
+                            PrintWriter noticeWriter,
+                            String defaultDocletClassName,
+                            String[] args)
+  {
+    // not yet implemented
+  }*/
+
   /**
    * Parses command line arguments and subsequentially handles control to the
    * startDoclet() method
@@ -1280,6 +1361,13 @@ public final class Main
           option_all = true;
         }
       });
+    options.put("-reflection", new OptionProcessor(1)
+      {
+        void process(String[] args)
+        {
+          option_reflection = true;
+        }
+      });
   }
 
   /**
@@ -1410,6 +1498,7 @@ public final class Main
             + "                          description and all tags, only generate declarations\n"
             + "\n"
             + "Gjdoc extension options:\n"
+            + "  -reflection             Use reflection for resolving unqualified class names\n"
             + "  -licensetext            Include license text from source files\n"
                /**
             + "  -genhtml                Generate HTML code instead of XML code. This is the\n"
@@ -1611,4 +1700,9 @@ public final class Main
     }
     return gjdocVersion;
   }
+
+  public boolean isReflectionEnabled()
+  {
+    return this.option_reflection;
+  }
 }
